@@ -1,5 +1,7 @@
-// FIXME: There are two mcs files; what is going on? Do not remember!!!
-// FIXME: mcsMAT0 is used in get-clices; guess mcsMAT0 is 0-based indexing.
+// FIXME: mcsMAT0 is used in get-clices; guess mcsMAT0 is 0-based
+// indexing.  mcsMAT0 is not visible on R side; only used once
+// in cpp code in gRbase; no idea about the other gR-packages.
+
 
 /*
   MAXIMUM CARDINALITY SEARCH on undirected graph. 
@@ -19,18 +21,11 @@
 
 */
 
+#include "_g_mcsMAT2.h"
 #include <RcppEigen.h>
 //[[Rcpp::depends(RcppEigen)]]
 //[[Rcpp::interfaces(r,cpp)]]
 
-#ifndef BEGIN_RCPP
-#define BEGIN_RCPP
-#endif
-
-#ifndef END_RCPP
-#define END_RCPP
-#endif
-
 using namespace Rcpp;
 using namespace Eigen;
 using namespace std;
@@ -87,8 +82,8 @@ bool do_is_complete_dense( const NumericMatrix& X, const IntegerVector& idx){
   } else {
     for (i=0; i<N-1; ++i){
       for (j=i+1; j<N; ++j){
-		//Rprintf("i=%d j=%d idx_s[i]=%d idx_s[j]=%d\n", i, j, idx_s[i], idx_s[j]);
-		if( X( idx_s[i], idx_s[j]) == 0) return false;
+	//Rprintf("i=%d j=%d idx_s[i]=%d idx_s[j]=%d\n", i, j, idx_s[i], idx_s[j]);
+	if( X( idx_s[i], idx_s[j]) == 0) return false;
       }      
     }
     return true;
@@ -247,7 +242,7 @@ SEXP do_mcs_dense  ( const NumericMatrix& X, const IntegerVector& mcs0idx ){
 }
 
 
-SEXP mcsMAT0_ ( SEXP XX_, SEXP mcs0idx_=R_NilValue ){
+SEXP mcsMAT0_ ( SEXP XX_, SEXP mcs0idx_){
   RObject zz_ = mcs0idx_;
   IntegerVector mcs0idx;
   int type = TYPEOF(XX_) ;  //Rf_PrintValue(wrap(type));
@@ -269,6 +264,17 @@ SEXP mcsMAT0_ ( SEXP XX_, SEXP mcs0idx_=R_NilValue ){
   return R_NilValue ;
 }
 
+
+
+// #ifndef BEGIN_RCPP
+// #define BEGIN_RCPP
+// #endif
+
+// #ifndef END_RCPP
+// #define END_RCPP
+// #endif
+
+
 /*** R
 
 library(gRbase)
